Price Model
===========

.. currentmodule:: hpipy.price_model

.. autosummary::
   :toctree: _autosummary
   :template: class.rst

   RepeatTransactionModel
   HedonicModel

.. currentmodule:: hpipy.extensions

.. autosummary::
   :toctree: _autosummary
   :template: class.rst

   RandomForestModel
   NeuralNetworkModel
